<?php

declare(strict_types=1);

namespace Dedi\SyliusReorderPlugin\ErrorHandler;

use Sylius\Component\Core\Model\OrderItemInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\HttpFoundation\Session\Session;

class ReoderItemErrorHandler implements ReoderItemErrorHandlerInterface
{
    public function __construct(private readonly RequestStack $requestStack)
    {
    }

    public function handle(string $message, array $items, string $type = 'error'): void
    {
        $request = $this->requestStack->getCurrentRequest();

        if (!$request instanceof Request) {
            return;
        }

        /** @var Session $session */
        $session = $request->getSession();
        $flashBag = $session->getFlashBag();

        $itemsNames = array_map(
            static fn (OrderItemInterface $item) => $item->getVariant()?->getProduct()?->getName(),
            $items,
        );

        $itemsNames = array_filter($itemsNames);

        $message = sprintf($message . ': %s', implode(', ', $itemsNames));

        $flashBag->add($type, $message);
    }
}
